import { defineComponent, nextTick, onMounted, reactive, ref } from 'vue';
import styles from './index.module.less';
import { NButton, NForm, NFormItem, NImage, NSpace } from 'naive-ui';
import iconAdd from '../../images/icon-add.png';
import TheSearch from '/src/components/TheSearch';
import { resourceTypeArray } from '/src/utils/searchArray';
import { useCatchStore } from '/src/store/modules/catchData';
import isCollaose from '../../images/isCollaose.png';
export default defineComponent({
  name: 'search-group',
  emits: ['search', 'add'],
  expose: ['init'],
  setup(props, { emit }) {
    const catchStore = useCatchStore();
    const forms = reactive({
      type: 'MUSIC', //
      name: '',
      bookVersionId: null,
      subjectId: null
    });

    const onSearch = () => {
      emit('search', forms);
    };
    const collapseWrapRef = ref();
    const divDomList = ref([] as any);
    const orginHeight = ref(0);
    const line = ref(0);
    const isCollapse = ref(false);
    const loadingCollapse = ref(false); // 是否加载完成
    const musicCateRef = (el: any) => {
      if (el?.selfElRef) {
        divDomList.value.push(el.selfElRef.parentNode);
      }
    };
    const setCollapse = (flag: boolean) => {
      isCollapse.value = flag;
      getLive();
    };
    const getLive = () => {
      try {
        divDomList.value = [...new Set(divDomList.value)];
        let offsetLeft = -1;
        divDomList.value.forEach((item: any, index: number) => {
          if (index === 0) {
            line.value = 1;
            offsetLeft = item.offsetLeft;
          } else if (item.offsetLeft === offsetLeft && index != 0) {
            // 如果某个标签的offsetLeft和第一个标签的offsetLeft相等  说明增加了一行
            line.value++;
          }
          if (!isCollapse.value) {
            if (line.value > 1) {
              //从第3行开始 隐藏标签
              item.style.display = 'none';
              // 显示展开按钮  class名chu是在前面动态添加的
            } else {
              item.style.display = 'block';
            }
          } else {
            item.style.display = 'block';
          }
        });
        loadingCollapse.value = true;
      } catch {
        //
      }
    };
    onMounted(async () => {
      console.log('加载');
      // 获取教材分类列表
      await catchStore.getMusicSheetCategory();
      // 获取声部列表
      await catchStore.getSubjects();

      if (forms.type === 'MUSIC') {
        orginHeight.value = collapseWrapRef.value.offsetHeight;
        // hiddenHeight.value = collapseWrapRef.value.offsetHeight / line.value;
        // 默认隐藏
        getLive();
      }
    });
    return () => (
      <div class={styles.searchGroup}>
        <div class={[styles.searchCatatory]}>
          <NSpace size="small" class={styles.btnType}>
            {resourceTypeArray.map((item: any) => (
              <NButton
                type={forms.type === item.value ? 'primary' : 'default'}
                secondary={forms.type === item.value ? false : true}
                round
                size="small"
                focusable={false}
                onClick={() => {
                  forms.type = item.value;
                  onSearch();

                  nextTick(() => {
                    if (forms.type === 'MUSIC') {
                      orginHeight.value = collapseWrapRef.value.offsetHeight;
                      // hiddenHeight.value =
                      //   collapseWrapRef.value.offsetHeight / line.value || 0;
                      // 默认隐藏
                      getLive();
                    } else {
                      divDomList.value = [];
                    }
                  });
                }}>
                {item.label}
              </NButton>
            ))}
          </NSpace>

          {/* <NButton
            type="primary"
            class={styles.addTrain}
            focusable={false}
            strong
            onClick={() => emit('add')}>
            <img src={iconAdd} />
            添加自定义教材
          </NButton> */}
        </div>
        <NForm labelAlign="left" labelPlacement="left">
          {forms.type === 'MUSIC' && (
            <div class={[styles.collapsSection]}>
              <NFormItem label="教材：">
                <div
                  class={[
                    styles.collapseWrap,
                    loadingCollapse.value ? '' : styles.hideButton,
                    isCollapse.value ? '' : styles.isHidden
                  ]}
                  ref={collapseWrapRef}>
                  <NSpace class={[styles.spaceSection]}>
                    {catchStore.getAllMusicCategories.map((music: any) => (
                      <NButton
                        ref={musicCateRef}
                        secondary={forms.bookVersionId === music.id}
                        quaternary={forms.bookVersionId !== music.id}
                        strong
                        focusable={false}
                        type={
                          forms.bookVersionId === music.id
                            ? 'primary'
                            : 'default'
                        }
                        onClick={() => {
                          forms.bookVersionId = music.id;
                          onSearch();
                        }}>
                        {music.name}
                      </NButton>
                    ))}
                    {line.value > 1 && (
                      <div
                        style={{
                          height: 'var(--n-blank-height)',
                          position: 'absolute',
                          display: 'flex',
                          alignItems: 'center'
                        }}
                        onClick={() => {
                          setCollapse(!isCollapse.value);
                        }}>
                        <NImage
                          previewDisabled
                          src={isCollaose}
                          class={[
                            styles.collaoseBtn,
                            isCollapse.value ? styles.isStart : ''
                          ]}></NImage>
                      </div>
                    )}
                  </NSpace>
                </div>
              </NFormItem>
            </div>
          )}

          <NFormItem label="乐器：">
            <NSpace class={styles.spaceSection}>
              {catchStore.getSubjectAllList.map((subject: any) => (
                <NButton
                  secondary={forms.subjectId === subject.id}
                  quaternary={forms.subjectId !== subject.id}
                  strong
                  focusable={false}
                  type={forms.subjectId === subject.id ? 'primary' : 'default'}
                  onClick={() => {
                    forms.subjectId = subject.id;
                    onSearch();
                  }}>
                  {subject.name}
                </NButton>
              ))}
            </NSpace>
          </NFormItem>

          <TheSearch
            class={styles.inputSearch}
            round
            onSearch={(val: string) => {
              forms.name = val;
              onSearch();
            }}
          />
        </NForm>
      </div>
    );
  }
});
